@@ -4,6 +4,8 @@ import json
 from functools import partial
 import requests
 
+from rainiee_data.utils import upass
+
 
 class DataApi:
     def __init__(self, token=None, timeout=6000):
@@ -14,7 +16,7 @@ class DataApi:
             API接口TOKEN，用于用户认证
         """
         self.__timeout = timeout
-        self.__http_url = 'https://data.rainiee.com/api/v1.0/{}'
+        self.__http_url = upass.get_host() + '/api/v1.0/{}'
         self.__token = token
 
     def query(self, api_name, method_type, req_param):
